MakeTransferOptions class

Implemented types

Constructors

MakeTransferOptions({required String amount, required String destination, required Keypair owner, Commitment? commitment, String? mint, String? referenceId, String? referenceType, bool? senderCreate, TransactionType? type})

Properties

amount ↔ String
getter/setter pairoverride
commitment ↔ Commitment?
getter/setter pair
destination ↔ String
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
mint ↔ String?
getter/setter pair
owner ↔ Keypair
getter/setter pair
referenceId ↔ String?
getter/setter pair
referenceType ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderCreate ↔ bool?
getter/setter pair
type ↔ TransactionType?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited