Keypair class

Constructors

Keypair({required Ed25519HDKeyPair solanaKeypair, required String secretKey, String? mnemonic})

Properties

hashCode → int
The hash code for this object.
no setterinherited
mnemonic → String?
final
publicKey ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretKey → String
final
solana → dynamic
no setter
solanaPublicKey → Ed25519HDPublicKey
no setter
solanaSecretKey → Future<List<int>>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

derive(List<int> sd, String hdPath) → Future<Keypair>
fromByteArray(List<int> bytes) → Future<Keypair>
fromMnemonic(String mnemonic) → Future<Keypair>
fromMnemonicSet(String mnemonic, [int? from = 0, dynamic to = 10]) → Future<List<Keypair>>
fromSecretKey(String secretKey) → Future<Keypair>
fromSeed(List<int> seed) → Future<Keypair>
generateMnemonic([int? strength = 128]) → String
random() → Future<Keypair>