Solana class

Constructors

Solana({required String solanaRpcEndpoint, String? solanaWssEndpoint, Duration timeoutDuration = const Duration(seconds: 60)})

Properties

client ↔ SolanaClient
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited